@@ -30,11 +30,11 @@ identifier.
 
 package Coro::SemaphoreSet;
 
-BEGIN { eval { require warnings } && warnings->unimport ("uninitialized") }
+no warnings;
 
 use Coro ();
 
-$VERSION = 4.72;
+$VERSION = 4.73;
 
 =item new [inital count]
 
